@@ -2,7 +2,7 @@ package App::Yath::Plugin::SysInfo;
 use strict;
 use warnings;
 
-our $VERSION = '2.000000'; # TRIAL
+our $VERSION = '2.000001'; # TRIAL
 
 use Sys::Hostname qw/hostname/;
 use Test2::Util qw/CAN_THREAD CAN_REALLY_FORK CAN_FORK CAN_SIGSYS/;
@@ -28,7 +28,7 @@ sub run_fields {
             user  => $ENV{USER},
             shell => $ENV{SHELL},
             term  => $ENV{TERM},
-            (map { m/(YATH|T2|TEST2|HARNESS|PERL|CPAN|TAP)/i ? ($_ => $ENV{$_}) : ()} grep keys %ENV),
+            (map { m/(YATH|T2|TEST2|HARNESS|PERL|CPAN|TAP)/i ? ($_ => $ENV{$_}) : ()} keys %ENV),
         },
 
         ipc => {
