@@ -1,5 +1,5 @@
 package App::Yath::Schema::Overlay::Run;
-our $VERSION = '2.000000'; # TRIAL
+our $VERSION = '2.000001'; # TRIAL
 
 package
     App::Yath::Schema::Result::Run;
@@ -91,7 +91,7 @@ sub expanded_coverage {
     $self->coverage->search(
         $query,
         {
-            order_by   => [qw/test_file_id source_file_id source_sub_id/],
+            order_by   => [qw/me.test_file_id me.source_file_id me.source_sub_id/],
             join       => [qw/test_file source_file source_sub coverage_manager/],
             '+columns' => {
                 test_file   => 'test_file.filename',
